pub fn read_password() -> Result<Vec<u8>, Error>Expand description
Reads a password from stdin without echoing it to the terminal.
The returned bytes do not include the trailing newline.
Mimics the behaviour of Go’s golang.org/x/term.ReadPassword.